@@ -16,11 +16,11 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: clustermap.pl,v 1.4 2005/04/21 16:17:18 fletcherpenney Exp $</p>';
+$ModulesDescription .= '<p>$Id: clustermap.pl,v 1.9 2005/08/19 23:46:32 fletcherpenney Exp $</p>';
 
 use vars qw($ClusterMapPage $ClusterMapTOC $FilterUnclusteredRegExp @ClusterMapAdminPages);
 
-$ClusterMapPage = "ClusterMap" unless defined $ClusterMapPage;
+$ClusterMapPage = "Site_Map" unless defined $ClusterMapPage;
 
 # Don't list the following pages as unclustered
 # By default, journal pages and Comment pages
@@ -31,7 +31,7 @@ $FilterUnclusteredRegExp = '\d\d\d\d-\d\d-\d\d|\d* *Comments on .*'
 # are not classified as unclustered.
 # They are also added to the Important Pages list on the administration page
 @ClusterMapAdminPages = ( $HomePage, $DeletedPage, $BannedContent,
-	$BannedHosts, $InterMap, $NearMap, $RCName)
+	$BannedHosts, $InterMap, $NearMap, $RCName, $RssExclude)
 	
 	unless defined @ClusterMapAdminPages;
 	
@@ -55,7 +55,7 @@ push (@AdminPages, @ClusterMapAdminPages);
 
 
 sub ClusterMapRule {
-	if (/\G^([\n\r]*\&lt;\s*clustermap\s*\&gt;\s*)$/mgc) {
+	if (/\G^([\n\r]*\<\s*clustermap\s*\>\s*)$/mgc) {
 		Dirty($1);
 		my $oldpos = pos;
 		$oldstr = $_;
@@ -64,7 +64,7 @@ sub ClusterMapRule {
 							# if <clustermap> isn't put into a new paragraph
 		PrintClusterMap();
 		pos = $oldpos;
-		$oldstr =~ s/.*?\&lt;\s*clustermap\s*\&gt;//s;
+		$oldstr =~ s/.*?\<\s*clustermap\s*\>//s;
 		$_ = $oldstr;
 		return '';
 	}
@@ -116,21 +116,24 @@ sub PrintClusterMap {
 	foreach my $cluster (sort keys %ClusterMap) {
 	    local %Page;
 	    local $OpenPageName='';
+		my $free = $cluster;
+		$free =~ s/_/ /g;
 
 		OpenPage($cluster);
 		
-		if ( GetCluster($Page{text}) eq $cluster ) {
+		if ( FreeToNormal(GetCluster($Page{text})) eq $cluster ) {
 			# Don't display the page name twice if the cluster page is also
 			# a member of the cluster
-			$Page{text} =~ s/^\[*$cluster\]*\n//s;
+			$Page{text} =~ s/^\[*$cluster\]*\n*//s;
+			$Page{text} =~ s/^\[*$free\]*\n*//s;
 		}
 
 		if ($PrintTOCAnchor) {
-			print $q->h1("<a id=\"toc$TOCCount\"></a>" . GetPageOrEditLink($cluster, $cluster));
+			print $q->h1("<a id=\"toc$TOCCount\"></a>" . GetPageOrEditLink($free, $free));
 			$TOCCount++;
 
 		} else {
-			print $q->h1(GetPageOrEditLink($cluster, $cluster));
+			print $q->h1(GetPageOrEditLink($free, $free));
 		}
 		PrintWikiToHTML($Page{text}, 0);
 		
@@ -147,21 +150,23 @@ sub PrintClusterMap {
 sub CreateClusterMap {
 	my @pages = AllPagesList();
 	
-    local %Page;
-    local $OpenPageName='';
+	local %Page;
+	local $OpenPageName='';
 	
 	foreach my $page ( @pages) {
 		OpenPage($page);
-		my $cluster = GetCluster($Page{text});
+		my $cluster = FreeToNormal(GetCluster($Page{text}));
 		
 		next if ($cluster eq $DeletedPage);		# Don't map Deleted Pages
 		
+		next if (TextIsFile($Page{text}));		# Don't map files
+		
 		if ($cluster eq "") {					# Grab Unclustered Pages
 			$Unclustered{$page} = 1;
 			next;
 		}
 		
-		if ($cluster ne $page) {				# Create Cluster Map
+		if ($cluster ne FreeToNormal($page)) {				# Create Cluster Map
 			$ClusterMap{$cluster}{$page} = 1;
 		}
 	}
@@ -210,4 +215,38 @@ sub ClusterMapAdminRule {
 	
 	push(@$menuref, ScriptLink('action=clustermap', T('Clustermap')));
 	push(@$menuref, ScriptLink('action=unclustered', T('Pages without a Cluster')));	
-}
\ No newline at end of file
+}
+
+*OldBrowseResolvedPage = *BrowseResolvedPage;
+*BrowseResolvedPage = *ClusterMapBrowseResolvedPage;
+
+sub ClusterMapBrowseResolvedPage {
+	my $title = shift;
+	$title =~ s/_/ /g;
+	my $id = FreeToNormal($title);
+	if ($id eq $ClusterMapPage) {
+		CreateClusterMap();
+		print GetHeader('',$title,'');
+		PrintClusterMap();
+		PrintFooter();
+	} else {
+		OldBrowseResolvedPage($id);
+	}
+}
+
+*OldPrintWikiToHTML = *PrintWikiToHTML;
+*PrintWikiToHTML = *ClusterMapPrintWikiToHTML;
+
+sub ClusterMapPrintWikiToHTML {
+	my ($pageText, $savecache, $revision, $islocked) = @_;
+
+	# Cause an empty page with the name $ClusterMapPage to
+	# display a map.
+	if (($ClusterMapPage eq $OpenPageName)
+		&& ($pageText =~ /^\s*$/s)){
+		SetParam('rcclusteronly',0);
+		CreateClusterMap();
+		PrintClusterMap();
+	}
+	OldPrintWikiToHTML(@_);
+}
