@@ -1,7 +1,7 @@
 # UTF-8 encoded German translation file for use with Oddmuse
 #
 # Copyright (c) 2003  Karl Loncarek <karl@loncarek.de>
-# Copyright (c) 2003, 2004  Alex Schröder <alex@emacswiki.org>
+# Copyright (c) 2003, 2004, 2005  Alex Schröder <alex@emacswiki.org>
 #
 # Permission is granted to copy, distribute and/or modify this
 # document under the terms of the GNU Free Documentation License,
@@ -16,8 +16,8 @@
 # Create a modules subdirectory in your data directory, and put the
 # file in there. It will be loaded automatically.
 #
-$ModulesDescription .= '<p>$Id: german-utf8.pl,v 1.3 2005/07/02 00:03:28 as Exp $</p>';
-%Translate = split('\n',<<END_OF_TRANSLATION);
+$ModulesDescription .= '<p>$Id: german-utf8.pl,v 1.7 2005/10/09 12:48:35 as Exp $</p>';
+%Translate = split(/\n/,<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 Lesen nicht erlaubt: Benutzer, IP oder Netzwerk ist gesperrt.
 Could not create %s
@@ -49,7 +49,7 @@ image
 download
 
 CGI Internal error: %s
-
+Interner CGI Fehler: %s
 Invalid action parameter %s
 Ungültiger action Parameter: %s
 Invalid URL.
@@ -104,6 +104,10 @@ List later changes
 Spätere Änderungen
 Filters
 Filter
+Title:
+Seitenname:
+Title and Body:
+Seitenname und Inhalt:
 Username:
 Benutzername:
 Host:
@@ -120,6 +124,8 @@ new
 Neue Seite
 from %s
 von %s
+This page is too big to send over RSS.
+Diese Seite ist zu gross für RSS.
 History of %s
 Andere Versionen von %s
 Compare
@@ -144,8 +150,6 @@ Wiki Version
 Wiki Version
 Unlock Wiki
 Aufheben der Sperren
-Recent Visitors
-Kürzliche Besucher
 Password
 Passwort
 Run maintenance
@@ -154,6 +158,8 @@ Unlock site
 Wiki entsperren
 Lock site
 Wiki sperren
+Install CSS
+
 Unlock %s
 %s entsperren
 Lock %s
@@ -238,6 +244,8 @@ minor
 kleinere
 No diff available.
 Keine Unterschiede vorhanden.
+The two revisions are the same.
+Es gibt keinen Unterschied zwischen den beiden Versionen.
 Old revision:
 Alte Version:
 Changed:
@@ -273,21 +281,21 @@ Erzwungene Aufhebung der Sperre von %s.
 No unlock required.
 Aufhebung der Sperre nicht notwendig.
 %s hours ago
-%s Stunden vorher
+vor %s Stunden
 1 hour ago
-eine Stunde vorher
+vor einer Stunde
 %s minutes ago
-%s Minuten vorher
+vor %s Minuten
 1 minute ago
-eine Minute vorher
+vor einer Minute
 %s seconds ago
-%s Sekunden vorher
+vor %s Sekunden
 1 second ago
-eine Sekunde vorher
+vor einer Sekunde
 just now
-genau jetzt
-Editing Denied
-Bearbeitung verweigert
+gerade eben
+Edit Denied
+Bearbeiten verboten
 Editing not allowed: user, ip, or network is blocked.
 Bearbeitung nicht erlaubt: Benutzer, IP oder Netzwerk ist gesperrt.
 Contact the wiki administrator for more information.
@@ -325,17 +333,17 @@ Ihr Passwort wird in einem Cookie gespeichert, falls Sie Cookies eingeschaltet h
 You are currently an administrator on this site.
 Sie sind momentan ein Administrator auf dieser Webseite.
 You are currently an editor on this site.
-Sie sind momentan ein Bearbeiter auf dieser Webseite.
+Sie sind momentan ein Redaktor auf dieser Webseite.
 You are a normal user on this site.
 Sie sind ein normaler Benutzer auf dieser Webseite.
 Your password does not match any of the  administrator or editor passwords.
-Ihr Passwort stimmt nicht mit einem Administrator- oder Bearbeiter-Passwort überein.
+Ihr Passwort stimmt nicht mit einem Administrator- oder Redaktor-Passwort überein.
 Password:
 Passwort:
 This site does not use admin or editor passwords.
-Diese Webseite verwendet keine Administrator- oder Bearbeiter-Passwörter.
+Diese Webseite verwendet keine Administrator- oder Redaktor-Passwörter.
 This operation is restricted to site editors only...
-Diese Aktion darf nur von Bearbeitern durchgeführt werden...
+Diese Aktion darf nur von Redaktoren durchgeführt werden...
 This operation is restricted to administrators only...
 Diese Aktion darf nur von Administratoren durchgeführt werden...
 Rule "%1" matched "%2" on this page.
@@ -354,6 +362,8 @@ Include near pages
 Mit Seiten aus der Umgebung
 (for %s)
 (für %s)
+Filter:
+Filter:
 %s pages found.
 %s Seiten gefunden.
 Replaced: %s
@@ -398,10 +408,10 @@ Browser reports no file info.
 Der Browser hat keine Dateiinformationen geliefert.
 Browser reports no file type.
 Der Browser hat keinen Dateityp geliefert.
-Edit Denied
-Bearbeiten verboten
 The page contains banned text.
 Diese Seite enthält verbotenen Text.
+No changes to be saved.
+
 This page was changed by somebody else %s.
 Diese Seite wurde von einer anderen Person %s verändert
 The changes conflict.  Please check the page again.
@@ -425,7 +435,7 @@ Vorgänger
 other
 Andere Person
 Run Maintenance
-Wartungsargeiten
+Wartungsarbeiten
 Maintenance not done.
 Wartungsarbeiten nicht erfolgt.
 (Maintenance can only be done once every 12 hours.)
@@ -484,6 +494,8 @@ Click to search for references to this permanent anchor
 Klicken um nach Verweisen auf diesen permanenten Anker zu suchen
 the page %s also exists
 die Seite %s existiert ebenfalls
+Copy one of the following stylesheets to %s:
+
 Deleting %s
 %s löschen
 Deleted %s
@@ -508,6 +520,14 @@ Rename %s to:
 %s umbenennen zu:
 Cannot highlight the language %s.
 Die Sprache %s kann von diesem Modul nicht eingefärbt werden.
+Recent Visitors
+Kürzliche Besucher
+some action
+Spezialaktion
+was here
+war hier
+and read
+und las
 Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
 Um einen Kalender zu produzieren fehlt entweder cal(1), Date::Calc(3) oder Date::Pcalc(3).
 The match parameter is missing.
@@ -523,7 +543,7 @@ Kalender %s
 Clustermap
 
 Pages without a Cluster
-
+Seiten ohne Cluster
 Comments on 
 Kommentare zu 
 Comment on 
@@ -542,10 +562,18 @@ Marked as %s.
 Mit %s markiert. 
 Cannot find unspammed revision.
 Es gibt keine Version ohne Spam.
+Add Comment
+Kommentar hinzufügen
+ordinary changes
+normale Änderungen
 Footnotes:
 Fussnoten:
 Could not find %1.html template in %2
 Im Verzeichnis %2 gibt es kein %1.html Template
+Only Editors are allowed to see hidden pages.
+Nur Redaktoren dürfen versteckte Seiten sehen.
+Only Admins are allowed to see hidden pages.
+Nur Administratoren dürfen versteckte Seiten sehen.
 image: %s
 Bild: %s
 Index
@@ -563,42 +591,100 @@ Vorlage ohne Parameter
 The template %s is either empty or does not exist.
 Die %s Vorlage ist entweder leer oder existiert gar nicht.
 Register for %s
-
+Anmeldung für %s
 Please choose a username of the form "FirstLast" using your real name.
-
+Bitte verwenden sie ihren Vorname und Nachname ohne Leerzeichen ("VornameNachname") als ihren Benutzernamen.
 The passwords do not match.
-
+Das Passwort stimmt nicht mit der Kopie überein.
 The password must be at least %s characters.
-
+Das Passwort muss mindestens %s Zeichen lang sein.
 That email address is invalid.
-
+Diese Email Adresse ist ungültig.
 The username %s has already been registered.
-
+Der Benutzername %s existiert bereits.
 Your registration for %s has been submitted.
-
+Ihre Anmeldung für den Benutzername %s wurde weitergeleitet.
   Please allow time for the webmaster to approve your request.
+  Bitte geben sie dem Webmaster etwas Zeit, um ihre Anmeldung entgegen zu nehmen.
+  An email has been sent to "%s" with further instructions.
+
+There was an error saving your registration.
 
 An account was created for %s.
-
+Der Benutzername %s wurde angelegt.
 Login to %s
-
+Anmeldung für %s
 Username and/or password are incorrect.
-
+Benutzername und/oder Passwort sind falsch.
 Logged in as %s.
-
+%s wurde erfolgreich angemeldet.
 Logout of %s
-
-Logout of %s?
+%s wurde erfolgreich abgemeldet.
+<p>Logout of %s?</p>
 
 Logged out of %s
-
+%s wurde erfolgreich abgemeldet.
 You are now logged out.
-
+Sie sind nun abgemeldet.
 Register a new account
-
+Neue Anmeldung
 Login
-
+Anmeldung
 Logout
+Abmeldung
+Who am I?
+
+Forgot your password?
+
+Change your password
+
+Approve pending registrations
+
+Confirm Registration for %s
+
+%s, your registration has been approved. You can now use your password to login and edit this wiki.
+
+Confirmation failed.  Please email %s for help.
+
+Who Am I?
+
+You are logged in as %s.
+
+You are not logged in.
+
+Reset Password
+
+The password for %s was reset.  It has been emailed to the address on file.
+
+There was an error resetting the password for %s
+
+The username "%s" does not exist.
+
+Reset Password for %s
+
+<p>Reset Password?</p>
+
+Change Password for %s
+
+<p>Change Password?</p>
+
+Your current password is incorrect.
+
+Your password has been changed.
+
+Approve Pending Registrations for %s
+
+%s has been approved.
+
+There was an error approving %s.
+
+<ul>
+
+<li>%1 - %2</li>
+
+</ul>
+
+There are no pending registrations.
 
 Clearing Cache
 Cache wird geleert
@@ -611,13 +697,17 @@ Die 404 handler Erweiterung benötigt die Link Data Erweiterung (links.pl).
 LocalMap
 
 No page id for action localmap
-
+Es gibt keine Spezialseite für den localmap Befehle
 Requested page %s does not exist
-
+Die gewünschte Seite %s existiert nicht
 Local Map for %s
 
 view
 
+Self-ban by %s
+%s hat sich selber verbannt.
+You have banned your own IP.
+Sie haben ihre eigene IP Nummer verbannt.
 Orphan List
 Liste der Waisen
 Trail: 
@@ -637,27 +727,31 @@ Alle Links auf diesen Wiki
 Referrers
 Links auf diese Seite
 Rebuild index for searching
-
+Der Index für die Suche wird neu erstellt
 Rebuilding Index
-
+Der Index wird neu erstellt
 Search::FreeText is not available on this system.
-
+Search::FreeText fehlt auf diesem System.
 Rebuilding index not done.
-
+Der Index für die Suche wurde noch nicht neu erstellt.
 (Rebuilding the index can only be done once every 12 hours.)
-
+(Der Index für die Suche kann nur einmal alle zwölf Stunden neu erstellt werden.)
 Search term missing.
-Suchbegriff fehlt.
+Der Suchbegriff fehlt.
 Result pages: 
-
+Resultate: 
 (%s results)
-
+(%s Resultate)
 Slideshow:%s
-
+Diashow:%s
 Static Copy
 Statische Kopie
 Back to %s
 Zurück zu %s
+Copy to %1 succeeded: %2.
+Die %1 Kopie hat funktioniert: %2.
+Copy to %1 failed: %2.
+Die %1 Kopie ist fehlgeschlagen: %2.
 Tag
 
 Alternatively, use one of the following templates:
@@ -694,8 +788,8 @@ The translation is outdated.
 Die Übersetzung ist veraltet.
 The page does not exist.
 Die Seite existiert nicht.
-http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s
-http://www.kelkoo.de/shopbot/search.jsp?from=shopbot&catPath=de%2Fbook&catId=100801&title=&author=&isbn=%s&maxprice=&x=36&y=9
+http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s
+
 http://www.amazon.com/exec/obidos/ISBN=%s
 http://www.amazon.de/exec/obidos/ISBN=%s
 alternate
@@ -704,6 +798,14 @@ http://www.pricescan.com/books/BookDetail.asp?isbn=%s
 http://de.bookbutler.info/vergleich/%s
 search
 Suchen
+Upload of %s file
+Hochladen der %s Datei
 Blog
 Blog
+Matching pages:
+Passende Seiten:
+New
+Neu
+Edit %s.
+%s bearbeiten.
 END_OF_TRANSLATION
