@@ -15,8 +15,8 @@
 # Create a modules subdirectory in your data directory, and put the
 # file in there. It will be loaded automatically.
 #
-$ModulesDescription .= '<p>$Id: new-utf8.pl,v 1.3 2005/07/02 00:03:28 as Exp $</p>';
-%Translate = split('\n',<<END_OF_TRANSLATION);
+$ModulesDescription .= '<p>$Id: new-utf8.pl,v 1.6 2005/10/09 12:48:35 as Exp $</p>';
+%Translate = split(/\n/,<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 
 Could not create %s
@@ -103,6 +103,10 @@ List later changes
 
 Filters
 
+Title:
+
+Title and Body:
+
 Username:
 
 Host:
@@ -119,6 +123,8 @@ new
 
 from %s
 
+This page is too big to send over RSS.
+
 History of %s
 
 Compare
@@ -143,8 +149,6 @@ Wiki Version
 
 Unlock Wiki
 
-Recent Visitors
-
 Password
 
 Run maintenance
@@ -153,6 +157,8 @@ Unlock site
 
 Lock site
 
+Install CSS
+
 Unlock %s
 
 Lock %s
@@ -237,6 +243,8 @@ minor
 
 No diff available.
 
+The two revisions are the same.
+
 Old revision:
 
 Changed:
@@ -285,7 +293,7 @@ No unlock required.
 
 just now
 
-Editing Denied
+Edit Denied
 
 Editing not allowed: user, ip, or network is blocked.
 
@@ -353,6 +361,8 @@ Include near pages
 
 (for %s)
 
+Filter:
+
 %s pages found.
 
 Replaced: %s
@@ -397,10 +407,10 @@ Browser reports no file info.
 
 Browser reports no file type.
 
-Edit Denied
-
 The page contains banned text.
 
+No changes to be saved.
+
 This page was changed by somebody else %s.
 
 The changes conflict.  Please check the page again.
@@ -483,6 +493,8 @@ Click to search for references to this permanent anchor
 
 the page %s also exists
 
+Copy one of the following stylesheets to %s:
+
 Deleting %s
 
 Deleted %s
@@ -507,6 +519,14 @@ Rename %s to:
 
 Cannot highlight the language %s.
 
+Recent Visitors
+
+some action
+
+was here
+
+and read
+
 Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
 
 The match parameter is missing.
@@ -541,10 +561,18 @@ Marked as %s.
 
 Cannot find unspammed revision.
 
+Add Comment
+
+ordinary changes
+
 Footnotes:
 
 Could not find %1.html template in %2
 
+Only Editors are allowed to see hidden pages.
+
+Only Admins are allowed to see hidden pages.
+
 image: %s
 
 Index
@@ -577,6 +605,10 @@ Your registration for %s has been submitted.
 
   Please allow time for the webmaster to approve your request.
 
+  An email has been sent to "%s" with further instructions.
+
+There was an error saving your registration.
+
 An account was created for %s.
 
 Login to %s
@@ -587,7 +619,7 @@ Logged in as %s.
 
 Logout of %s
 
-Logout of %s?
+<p>Logout of %s?</p>
 
 Logged out of %s
 
@@ -599,6 +631,60 @@ Login
 
 Logout
 
+Who am I?
+
+Forgot your password?
+
+Change your password
+
+Approve pending registrations
+
+Confirm Registration for %s
+
+%s, your registration has been approved. You can now use your password to login and edit this wiki.
+
+Confirmation failed.  Please email %s for help.
+
+Who Am I?
+
+You are logged in as %s.
+
+You are not logged in.
+
+Reset Password
+
+The password for %s was reset.  It has been emailed to the address on file.
+
+There was an error resetting the password for %s
+
+The username "%s" does not exist.
+
+Reset Password for %s
+
+<p>Reset Password?</p>
+
+Change Password for %s
+
+<p>Change Password?</p>
+
+Your current password is incorrect.
+
+Your password has been changed.
+
+Approve Pending Registrations for %s
+
+%s has been approved.
+
+There was an error approving %s.
+
+<ul>
+
+<li>%1 - %2</li>
+
+</ul>
+
+There are no pending registrations.
+
 Clearing Cache
 
 Done.
@@ -617,6 +703,10 @@ Local Map for %s
 
 view
 
+Self-ban by %s
+
+You have banned your own IP.
+
 Orphan List
 
 Trail: 
@@ -657,6 +747,10 @@ Static Copy
 
 Back to %s
 
+Copy to %1 succeeded: %2.
+
+Copy to %1 failed: %2.
+
 Tag
 
 Alternatively, use one of the following templates:
@@ -693,7 +787,7 @@ The translation is outdated.
 
 The page does not exist.
 
-http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s
+http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s
 
 http://www.amazon.com/exec/obidos/ISBN=%s
 
@@ -703,6 +797,14 @@ http://www.pricescan.com/books/BookDetail.asp?isbn=%s
 
 search
 
+Upload of %s file
+
 Blog
 
+Matching pages:
+
+New
+
+Edit %s.
+
 END_OF_TRANSLATION
