@@ -16,12 +16,7 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: usemod.pl,v 1.20 2005/01/06 11:35:04 as Exp $</p>';
-
-$DefaultStyleSheet .= <<'EOT' unless $DefaultStyleSheet =~ /table\.user/; # mod_perl?
-table.user { border-style:solid; border-width:thin; }
-table.user tr td { border-style:solid; border-width:thin; padding:5px; }
-EOT
+$ModulesDescription .= '<p>$Id: usemod.pl,v 1.25 2005/10/09 12:04:48 as Exp $</p>';
 
 use vars qw($RFCPattern $ISBNPattern @HtmlTags $HtmlTags $HtmlLinks $RawHtml
 	    $UseModSpaceRequired $UseModMarkupInTitles);
@@ -32,7 +27,7 @@ push(@MyRules, \&UsemodRule);
 $RuleOrder{\&UsemodRule} = 100;
 
 $RFCPattern  = 'RFC\\s?(\\d+)';
-$ISBNPattern = 'ISBN:?([0-9- xX]{10,})';
+$ISBNPattern = 'ISBN:?([0-9- xX]{10,14})';
 $HtmlLinks   = 0;   # 1 = <a href="foo">desc</a> is a link
 $RawHtml     = 0;   # 1 = allow <HTML> environment for raw HTML inclusion
 @HtmlTags    = ();  # List of HTML tags.  If not set, determined by $HtmlTags
@@ -112,9 +107,9 @@ sub UsemodRule {
     $PortraitSupportColor = 0;
     return $html;
   } elsif ($UseModMarkupInTitles
-	   && m/\G[ \t]*=+\n?/cg
 	   && (InElement('h1') || InElement('h2') || InElement('h3')
-		|| InElement('h4') || InElement('h5') || InElement('h6'))) {
+	       || InElement('h4') || InElement('h5') || InElement('h6'))
+	   && m/\G[ \t]*=+\n?/cg) {
     return CloseHtmlEnvironments() . AddHtmlEnvironment('p');
   } elsif ($bol && !$UseModMarkupInTitles && m/\G(\s*\n)*(\=+)[ \t]*(.+?)[ \t]*(=+)[ \t]*\n?/cg) {
     my $html = CloseHtmlEnvironments() . ($PortraitSupportColorDiv ? '</div>' : '')
@@ -209,21 +204,19 @@ sub RFC {
 
 sub ISBN {
   my $rawnum = shift;
-  my ($rawprint, $html, $num, $first, $second, $third);
-  $num = $rawnum;
-  $rawprint = $rawnum;
+  my $num = $rawnum;
+  my $rawprint = $rawnum;
   $rawprint =~ s/ +$//;
   $num =~ s/[- ]//g;
-  if (length($num) != 10) {
-    return "ISBN $rawnum";
-  }
-  $first  = $q->a({-href => Ts('http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s', $num)},
+  my $len = length($num);
+  return "ISBN $rawnum" unless $len == 10 or $len == 13 or $len = 14; # be prepared for 2007-01-01
+  my $first  = $q->a({-href => Ts('http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s', $num)},
 		  "ISBN " . $rawprint);
-  $second = $q->a({-href => Ts('http://www.amazon.com/exec/obidos/ISBN=%s', $num)},
+  my $second = $q->a({-href => Ts('http://www.amazon.com/exec/obidos/ISBN=%s', $num)},
 		  T('alternate'));
-  $third  = $q->a({-href => Ts('http://www.pricescan.com/books/BookDetail.asp?isbn=%s', $num)},
+  my $third  = $q->a({-href => Ts('http://www.pricescan.com/books/BookDetail.asp?isbn=%s', $num)},
 		  T('search'));
-  $html	 = "$first ($second, $third)";
+  my $html = "$first ($second, $third)";
   $html .= ' '	if ($rawnum =~ / $/);  # Add space if old ISBN had space.
   return $html;
 }
